@@ -1,3 +1,73 @@
+pub fn main() -> Option<i32> {
+    use colored::Colorize;
+
+    let cases = match test_all() {
+        Ok(tr) => tr,
+        Err(crate::Error::TestsFolderMissing) => {
+            eprintln!("{}", "Tests folder is missing".red());
+            return Some(1);
+        }
+        Err(crate::Error::TestsFolderNotReadable(e)) => {
+            eprintln!("{}", format!("Tests folder is unreadable: {:?}", e).red());
+            return Some(1);
+        }
+        Err(crate::Error::CantReadConfig(e)) => {
+            eprintln!("{}", format!("Cant read config file: {:?}", e).red());
+            return Some(1);
+        }
+        Err(crate::Error::InvalidConfig(e)) => {
+            eprintln!("{}", format!("Cant parse config file: {:?}", e).red());
+            return Some(1);
+        }
+        Err(crate::Error::BuildFailedToLaunch(e)) => {
+            eprintln!(
+                "{}",
+                format!("Build command failed to launch: {:?}", e).red()
+            );
+            return Some(1);
+        }
+        Err(crate::Error::BuildFailed(e)) => {
+            eprintln!("{}", format!("Build failed: {:?}", e).red());
+            return Some(1);
+        }
+    };
+
+    let mut any_failed = false;
+    for case in cases.iter() {
+        let duration = if is_test() {
+            "".to_string()
+        } else {
+            format!("in {}", format!("{:?}", &case.duration).yellow())
+        };
+
+        match &case.result {
+            Ok(status) => {
+                if *status {
+                    println!("{}: {} {}", case.id.blue(), "PASSED".green(), duration);
+                } else {
+                    println!("{}: {}", case.id.blue(), "SKIPPED".magenta(),);
+                }
+            }
+            Err(e) => {
+                any_failed = true;
+                println!(
+                    "{}: {} {} ({:?})",
+                    case.id.blue(),
+                    "FAILED".red(),
+                    duration,
+                    e
+                );
+            }
+        }
+    }
+
+    if any_failed {
+        return Some(2);
+    }
+
+    None
+}
+
 pub fn test_all() -> Result<Vec<crate::Case>, crate::Error> {
     let mut results = vec![];
 
@@ -62,7 +132,7 @@ pub fn test_all() -> Result<Vec<crate::Case>, crate::Error> {
             .map(|v| v.to_str())
             .unwrap_or(None)
             .unwrap_or("")
-            .starts_with(".")
+            .starts_with('.')
         {
             continue;
         }
@@ -221,7 +291,7 @@ fn test_one(global: &crate::Config, entry: std::path::PathBuf) -> crate::Case {
         None => dir,
     };
 
-    return crate::Case {
+    crate::Case {
         id: id.clone(),
         result: match crate::dir_diff::diff(output, reference) {
             Ok(Some(diff)) => {
@@ -231,5 +301,9 @@ fn test_one(global: &crate::Config, entry: std::path::PathBuf) -> crate::Case {
             Err(e) => return err(crate::Failure::DirDiffError { error: e }),
         },
         duration: std::time::Instant::now().duration_since(start),
-    };
+    }
+}
+
+fn is_test() -> bool {
+    std::env::args().any(|e| e == "--test")
 }
